/*
 * GNU.FREE 2002
 *
 * Copyright (c) 1999, 2000, 2001, 2002
 * The Free Software Foundation (www.fsf.org)
 *
 * GNU.FREE Co-ordinator: Jason Kitcat <jeep@free-project.org>
 *
 * GNU site: http://www.gnu.org/software/free/
 * 
 * FREE e-democracy site: http://www.free-project.org
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program (COPYING); if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 */

package FreeInstall;

import java.awt.*;
import java.awt.event.*;

import Free.awt.*;

 /**
  * A screen to let users easily set the FREE code variables.
  *
  * @version 0.3 10 April 2001
  * @author Jason Kitcat, Rajagopal C.V
  */
public class InstallFrame extends Frame 
{

	Label jLabel1 = new Label();
	Label jLabel2 = new Label();
	Label jLabel3 = new Label();
	Label jLabel4 = new Label();
	Label jLabel6 = new Label();
	Label jLabel7 = new Label();
	TextField jTextField1 = new TextField();
	TextField jTextField2 = new TextField();
	TextField jTextField3 = new TextField();
	TextField jTextField4 = new TextField();
	TextField jTextField5 = new TextField();
	Button jButton1 = new Button();
	Label jLabel5 = new Label();

	public Insets getInsets(){ return new Insets(30, 10, 10, 10);}

	protected InstallFrame() {
	
		jLabel4.setText("Please fill out fields for setup:");
		jLabel1.setText("Regional Server name:");
		jLabel2.setText("Electoral Roll Server name:");
		jLabel3.setText("Totaller Server name:");
		jLabel6.setText("ERServer port number (>1024):");
		jLabel7.setText("RTServer port number (>1024):");
		jLabel5.setText("Please fill out ALL the fields!");
		jButton1.setLabel("OK");
	
		FreePanel scrollPanel = new FreePanel("Installation");
		scrollPanel.setInsets(3, 3, 3, 3);
		
		scrollPanel.addComponent( 0, 0, 1, 2, 0, 0, GridBagConstraints.BOTH, 
			1.0f, 0.0f, jLabel4);
		scrollPanel.addComponent( 1, 0, 1, 1, 0, 0, GridBagConstraints.BOTH, 
			1.0f, 0.0f, jLabel1);
		scrollPanel.addComponent( 2, 0, 1, 2, 0, 0, GridBagConstraints.BOTH, 
			1.0f, 0.0f, jTextField1);
		scrollPanel.addComponent( 3, 0, 1, 1, 0, 0, GridBagConstraints.BOTH, 
			1.0f, 0.0f, jLabel2);
		scrollPanel.addComponent( 4, 0, 1, 2, 0, 0, GridBagConstraints.BOTH, 
			1.0f, 0.0f, jTextField2);
		scrollPanel.addComponent( 5, 0, 1, 1, 0, 0, GridBagConstraints.BOTH, 
			1.0f, 0.0f, jLabel3);
		scrollPanel.addComponent( 6, 0, 1, 2, 0, 0, GridBagConstraints.BOTH, 
			1.0f, 0.0f, jTextField3);
		scrollPanel.addComponent( 7, 0, 1, 1, 0, 0, GridBagConstraints.BOTH, 
			1.0f, 0.0f, jLabel6);
		scrollPanel.addComponent( 8, 0, 1, 2, 0, 0, GridBagConstraints.BOTH, 
			1.0f, 0.0f, jTextField4);
		scrollPanel.addComponent( 9, 0, 1, 1, 0, 0, GridBagConstraints.BOTH, 
			1.0f, 0.0f, jLabel7);
		scrollPanel.addComponent( 10, 0, 1, 2, 0, 0, GridBagConstraints.BOTH, 
			1.0f, 0.0f, jTextField5);
		scrollPanel.addComponent( 11, 0, 1, 1, 0, 0, GridBagConstraints.BOTH, 
			1.0f, 0.0f, jLabel5);

		scrollPanel.addComponent( 11, 1, 1, 1, 0, 0, GridBagConstraints.NONE, 
			1.0f, 0.0f, jButton1);
		add(scrollPanel);

		setLocation(new java.awt.Point(40, 40));
		setTitle("GNU.FREE: Setup (1)");
		setResizable(false);
		setSize(new java.awt.Dimension(300, 440));
	
	}

	protected void initComponents() throws Exception
	{

		jButton1.addActionListener(new java.awt.event.ActionListener() {
			public void actionPerformed(java.awt.event.ActionEvent e) {
				jButton1ActionPerformed(e);
			}
		});
		addWindowListener(new java.awt.event.WindowAdapter() {
			public void windowClosing(java.awt.event.WindowEvent e) {
				thisWindowClosing(e);
			}
		});
		
		jLabel5.setVisible(false);
	}

	// Close the window when the close box is clicked
	void thisWindowClosing(java.awt.event.WindowEvent e)
	{
	}
	
	protected void jButton1ActionPerformed(java.awt.event.ActionEvent e) {

		if (jTextField1.getText().equals("")|jTextField2.getText().equals("")|jTextField3.getText().equals("")|jTextField4.getText().equals("")|jTextField5.getText().equals("")) {
			jLabel5.setVisible(true);
		} else {
			if (Install.isSafe(jTextField1.getText())|Install.isSafe(jTextField2.getText())|Install.isSafe(jTextField3.getText())|Install.isSafe(jTextField4.getText())|Install.isSafe(jTextField5.getText())) {
				setVisible(false);
				jLabel5.setVisible(false);
			
				Install.regional_name = jTextField1.getText();
				Install.er_name = jTextField2.getText();
				Install.totaller_name = jTextField3.getText();
				Install.freePort = jTextField4.getText();
				Install.freeRTPort = jTextField5.getText();

				//Install.frame3.setVisible(true); HISTORIC
				Install.frame4.setVisible(true);
				dispose();
			} else {
				jLabel5.setVisible(true);
			}

		}
					
	}
} //EOF class
